# AnPaFinder
Version 1.0.0.a0 released 02/2022


This package is under construction. It is built off of this repository:
    https://github.com/AmryAnn/PythonCodeSample-Strings-Anagram_Palindrome_Finder

## Installation
`AnPaFinder` can be installed via `pip`:
```
$ python3 -m pip install AnPaFinder
```

-Find the anagrams and palindromes from a webpage using the scripts in the **Home Page - anpaFinder GitHub repository** under `/bin`:
 - In python environment: 
   ```
   $ python3 anpatools.py --url "<webpage url>"
   ```
 - In bash shell
   ```
   $ ./AP_finder.bash -w "<webpage url>"
   ```
-Play with classes and functions in `anpa_tools` package.
		